@@ -33,9 +33,10 @@
 #include <KConfigDialog> // IDW test.
 #include <KIO/CopyJob>
 #include <KIO/Job>
-#include <KJobWidgets/KJobWidgets>
+#include <KJobWidgets>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <kio_version.h>
 
 #include "prefs.h"
 
@@ -53,7 +54,7 @@ Game::Game (const int d, KCubeBoxWidget * view, QWidget * parent)
    m_newSettings        (false),
    m_parent             (parent),
    m_view               (view),
-   m_settingsPage       (0),
+   m_settingsPage       (nullptr),
    m_side               (d),
    m_currentPlayer      (One),
    m_index              (0),
@@ -362,7 +363,7 @@ void Game::doMove (int index)
    emit setAction (UNDO, true);	// Update Undo and Redo actions.
    emit setAction (REDO, false);
    m_steps->clear();
-   bool won = m_box->doMove (m_currentPlayer, index, 0, m_steps);
+   bool won = m_box->doMove (m_currentPlayer, index, nullptr, m_steps);
 #if AILog > 1
    qCDebug(KJUMPINGCUBE_LOG) << "GAME WON?" << won << "STEPS" << (* m_steps);
    // m_box->printBox();
@@ -579,7 +580,11 @@ void Game::saveGame (bool saveAs)
             url.setPath(url.path() +".kjc");
          }
 
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 69, 0)
+         KIO::StatJob* statJob = KIO::statDetails(url, KIO::StatJob::DestinationSide, KIO::StatNoDetails);
+#else
          KIO::StatJob* statJob = KIO::stat(url, KIO::StatJob::DestinationSide, 0);
+#endif
          KJobWidgets::setWindow(statJob, m_view);
          if (statJob->exec()) {
             QString mes=i18n("The file %1 exists.\n"
@@ -624,7 +629,11 @@ void Game::loadGame()
       url = QFileDialog::getOpenFileUrl (m_view, QString(), m_gameURL, QStringLiteral("*.kjc"));
       if (url.isEmpty())
          return;
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 69, 0)
+      KIO::StatJob* statJob = KIO::statDetails(url, KIO::StatJob::SourceSide, KIO::StatNoDetails);
+#else
       KIO::StatJob* statJob = KIO::stat(url, KIO::StatJob::SourceSide, 0);
+#endif
       KJobWidgets::setWindow(statJob, m_view);
       if (! statJob->exec()) {
          QString mes = i18n("The file %1 does not exist!", url.url());
